Contributing to the Oracle Cloud Infrastructure Python SDK
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.*
*This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.*

Pull requests can be made under
`The Oracle Contributor Agreement <https://www.oracle.com/technetwork/community/oca-486395.html>`_ (OCA).

For pull requests to be accepted, the bottom of
your commit message must have the following line using your name and
e-mail address as it appears in the OCA Signatories list.

::

  Signed-off-by: Your Name <you@example.org>

This can be automatically added to pull requests by committing with:

::

  git commit --signoff

Only pull requests from committers that can be verified as having
signed the OCA can be accepted.
